@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,9 @@
 #include "grantleetheme.h"
 #include "grantleetheme_p.h"
 #include "grantleetheme_debug.h"
+#include "grantleethemeengine.h"
 #include "config-grantleetheme.h"
+#include "qtresourcetemplateloader.h"
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -30,7 +32,7 @@
 using namespace GrantleeTheme;
 
 QSharedPointer<GrantleeKi18nLocalizer> GrantleeTheme::ThemePrivate::sLocalizer;
-Grantlee::Engine *GrantleeTheme::ThemePrivate::sEngine = Q_NULLPTR;
+Grantlee::Engine *GrantleeTheme::ThemePrivate::sEngine = nullptr;
 
 ThemePrivate::ThemePrivate()
     : QSharedData()
@@ -57,11 +59,7 @@ ThemePrivate::~ThemePrivate()
 
 void ThemePrivate::setupEngine()
 {
-    sEngine = new Grantlee::Engine;
-    sEngine->addPluginPath(QStringLiteral(GRANTLEE_PLUGIN_INSTALL_DIR));
-    sEngine->addDefaultLibrary(QStringLiteral("grantlee_i18ntags"));
-    sEngine->addDefaultLibrary(QStringLiteral("kde_grantlee_plugin"));
-    sEngine->setSmartTrimEnabled(true);
+    sEngine = new GrantleeTheme::Engine();
 }
 
 void ThemePrivate::setupLoader()
@@ -70,7 +68,7 @@ void ThemePrivate::setupLoader()
     QDir dir(absolutePath);
     dir.cdUp();
 
-    loader = QSharedPointer<Grantlee::FileSystemTemplateLoader>::create();
+    loader = QSharedPointer<GrantleeTheme::QtResourceTemplateLoader>::create();
     loader->setTemplateDirs({ dir.absolutePath() });
     loader->setTheme(dirName);
 
@@ -80,32 +78,33 @@ void ThemePrivate::setupLoader()
     sEngine->addTemplateLoader(loader);
 }
 
-Grantlee::Context ThemePrivate::createContext(const QVariantHash &data)
+Grantlee::Context ThemePrivate::createContext(const QVariantHash &data, const QByteArray &applicationDomain)
 {
     if (!sLocalizer) {
         sLocalizer.reset(new GrantleeKi18nLocalizer());
     }
-
+    sLocalizer->setApplicationDomain(applicationDomain);
     Grantlee::Context ctx(data);
     ctx.setLocalizer(sLocalizer);
     return ctx;
 }
 
-QString ThemePrivate::errorTemplate(const QString &reason,
-                                    const QString &origTemplateName,
-                                    const Grantlee::Template &failedTemplate)
+QString ThemePrivate::errorTemplate(const QString &reason, const QString &origTemplateName, const Grantlee::Template &failedTemplate)
 {
     Grantlee::Template tpl = sEngine->newTemplate(
-                                 QStringLiteral("<h1>{{ error }}</h1>\n"
-                                         "<b>%1:</b> {{ templateName }}<br>\n"
-                                         "<b>%2:</b> {{ errorMessage }}")
-                                 .arg(i18n("Template"), i18n("Error message")),
-                                 QStringLiteral("TemplateError"));
+        QStringLiteral("<h1>{{ error }}</h1>\n"
+                       "<b>%1:</b> {{ templateName }}<br>\n"
+                       "<b>%2:</b> {{ errorMessage }}")
+        .arg(i18n("Template"), i18n("Error message")),
+        QStringLiteral("TemplateError"));
 
     Grantlee::Context ctx = createContext();
     ctx.insert(QStringLiteral("error"), reason);
     ctx.insert(QStringLiteral("templateName"), origTemplateName);
-    ctx.insert(QStringLiteral("errorMessage"), failedTemplate->errorString());
+    const QString errorString = failedTemplate
+                                ? failedTemplate->errorString()
+                                : i18n("(null template)");
+    ctx.insert(QStringLiteral("errorMessage"), errorString);
     return tpl->render(&ctx);
 }
 
@@ -198,7 +197,7 @@ QString Theme::authorEmail() const
     return d->email;
 }
 
-QString Theme::render(const QString &templateName, const QVariantHash &data)
+QString Theme::render(const QString &templateName, const QVariantHash &data, const QByteArray &applicationDomain)
 {
     if (!d->loader) {
         d->setupLoader();
@@ -211,11 +210,11 @@ QString Theme::render(const QString &templateName, const QVariantHash &data)
     }
 
     Grantlee::Template tpl = d->loader->loadByName(templateName, ThemePrivate::sEngine);
-    if (tpl->error()) {
+    if (!tpl || tpl->error()) {
         return d->errorTemplate(i18n("Template parsing error"), templateName, tpl);
     }
 
-    Grantlee::Context ctx = d->createContext(data);
+    Grantlee::Context ctx = d->createContext(data, applicationDomain);
     const QString result = tpl->render(&ctx);
     if (tpl->error()) {
         return d->errorTemplate(i18n("Template rendering error"), templateName, tpl);
