@@ -22,19 +22,18 @@
 
 #include <grantlee/taglibraryinterface.h>
 
-class KDEGrantleePlugin : public QObject
-    , public Grantlee::TagLibraryInterface
+class KDEGrantleePlugin : public QObject, public Grantlee::TagLibraryInterface
 {
     Q_OBJECT
     Q_INTERFACES(Grantlee::TagLibraryInterface)
     Q_PLUGIN_METADATA(IID "org.kde.KDEGrantleePlugin")
 
 public:
-    explicit KDEGrantleePlugin(QObject *parent = Q_NULLPTR);
+    explicit KDEGrantleePlugin(QObject *parent = nullptr);
     ~KDEGrantleePlugin();
 
-    QHash<QString, Grantlee::Filter *> filters(const QString  &name) Q_DECL_OVERRIDE;
-    QHash<QString, Grantlee::AbstractNodeFactory *> nodeFactories(const QString &name) Q_DECL_OVERRIDE;
+    QHash<QString, Grantlee::Filter *> filters(const QString &name) override;
+    QHash<QString, Grantlee::AbstractNodeFactory *> nodeFactories(const QString &name) override;
 };
 
 #endif // KDEGRANTLEEPLUGIN_H
